"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "getErrorByType", {
    enumerable: true,
    get: function() {
        return _getErrorByType.getErrorByType;
    }
});
Object.defineProperty(exports, "getServerError", {
    enumerable: true,
    get: function() {
        return _nodeStackFrames.getServerError;
    }
});
Object.defineProperty(exports, "ReactDevOverlay", {
    enumerable: true,
    get: function() {
        return _reactDevOverlay.default;
    }
});
exports.onRefresh = exports.onBuildError = exports.onBuildOk = exports.unregister = exports.register = void 0;
var _interop_require_default = require("@swc/helpers/lib/_interop_require_default.js").default;
var _interop_require_wildcard = require("@swc/helpers/lib/_interop_require_wildcard.js").default;
var Bus = _interop_require_wildcard(require("./internal/bus"));
var _parseStack = require("./internal/helpers/parseStack");
var _getErrorByType = require("./internal/helpers/getErrorByType");
var _nodeStackFrames = require("./internal/helpers/nodeStackFrames");
var _reactDevOverlay = _interop_require_default(require("./internal/ReactDevOverlay"));
let isRegistered = false;
let stackTraceLimit = undefined;
function onUnhandledError(ev) {
    const error = ev == null ? void 0 : ev.error;
    if (!error || !(error instanceof Error) || typeof error.stack !== 'string') {
        // A non-error was thrown, we don't have anything to show. :-(
        return;
    }
    if (error.message.match(/(hydration|content does not match|did not match)/i)) {
        error.message += `\n\nSee more info here: https://nextjs.org/docs/messages/react-hydration-error`;
    }
    const e = error;
    Bus.emit({
        type: Bus.TYPE_UNHANDLED_ERROR,
        reason: error,
        frames: (0, _parseStack).parseStack(e.stack)
    });
}
function onUnhandledRejection(ev) {
    const reason = ev == null ? void 0 : ev.reason;
    if (!reason || !(reason instanceof Error) || typeof reason.stack !== 'string') {
        // A non-error was thrown, we don't have anything to show. :-(
        return;
    }
    const e = reason;
    Bus.emit({
        type: Bus.TYPE_UNHANDLED_REJECTION,
        reason: reason,
        frames: (0, _parseStack).parseStack(e.stack)
    });
}
function register() {
    if (isRegistered) {
        return;
    }
    isRegistered = true;
    try {
        const limit = Error.stackTraceLimit;
        Error.stackTraceLimit = 50;
        stackTraceLimit = limit;
    } catch (e) {}
    window.addEventListener('error', onUnhandledError);
    window.addEventListener('unhandledrejection', onUnhandledRejection);
}
function unregister() {
    if (!isRegistered) {
        return;
    }
    isRegistered = false;
    if (stackTraceLimit !== undefined) {
        try {
            Error.stackTraceLimit = stackTraceLimit;
        } catch (e) {}
        stackTraceLimit = undefined;
    }
    window.removeEventListener('error', onUnhandledError);
    window.removeEventListener('unhandledrejection', onUnhandledRejection);
}
function onBuildOk() {
    Bus.emit({
        type: Bus.TYPE_BUILD_OK
    });
}
function onBuildError(message) {
    Bus.emit({
        type: Bus.TYPE_BUILD_ERROR,
        message
    });
}
function onRefresh() {
    Bus.emit({
        type: Bus.TYPE_REFRESH
    });
}
exports.register = register;
exports.unregister = unregister;
exports.onBuildOk = onBuildOk;
exports.onBuildError = onBuildError;
exports.onRefresh = onRefresh;

if ((typeof exports.default === 'function' || (typeof exports.default === 'object' && exports.default !== null)) && typeof exports.default.__esModule === 'undefined') {
  Object.defineProperty(exports.default, '__esModule', { value: true });
  Object.assign(exports.default, exports);
  module.exports = exports.default;
}

//# sourceMappingURL=client.js.map