"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = void 0;
var _extends = require("@swc/helpers/lib/_extends.js").default;
var _interop_require_wildcard = require("@swc/helpers/lib/_interop_require_wildcard.js").default;
var React = _interop_require_wildcard(require("react"));
var Bus = _interop_require_wildcard(require("./bus"));
var _shadowPortal = require("./components/ShadowPortal");
var _buildError = require("./container/BuildError");
var _errors = require("./container/Errors");
var _errorBoundary = require("./ErrorBoundary");
var _base = require("./styles/Base");
var _componentStyles = require("./styles/ComponentStyles");
var _cssReset = require("./styles/CssReset");
function reducer(state, ev) {
    switch(ev.type){
        case Bus.TYPE_BUILD_OK:
            {
                return _extends({}, state, {
                    buildError: null
                });
            }
        case Bus.TYPE_BUILD_ERROR:
            {
                return _extends({}, state, {
                    buildError: ev.message
                });
            }
        case Bus.TYPE_REFRESH:
            {
                return _extends({}, state, {
                    buildError: null,
                    errors: []
                });
            }
        case Bus.TYPE_UNHANDLED_ERROR:
        case Bus.TYPE_UNHANDLED_REJECTION:
            {
                return _extends({}, state, {
                    nextId: state.nextId + 1,
                    errors: [
                        ...state.errors.filter((err)=>{
                            // Filter out duplicate errors
                            return err.event.reason !== ev.reason;
                        }),
                        {
                            id: state.nextId,
                            event: ev
                        }, 
                    ]
                });
            }
        default:
            {
                // eslint-disable-next-line @typescript-eslint/no-unused-vars
                const _ = ev;
                return state;
            }
    }
}
const shouldPreventDisplay = (errorType, preventType)=>{
    if (!preventType || !errorType) {
        return false;
    }
    return preventType.includes(errorType);
};
const ReactDevOverlay = function ReactDevOverlay({ children , preventDisplay , globalOverlay  }) {
    const [state, dispatch] = React.useReducer(reducer, {
        nextId: 1,
        buildError: null,
        errors: []
    });
    React.useEffect(()=>{
        Bus.on(dispatch);
        return function() {
            Bus.off(dispatch);
        };
    }, [
        dispatch
    ]);
    const onComponentError = React.useCallback((_error, _componentStack)=>{
    // TODO: special handling
    }, []);
    const hasBuildError = state.buildError != null;
    const hasRuntimeErrors = Boolean(state.errors.length);
    const isMounted = hasBuildError || hasRuntimeErrors;
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(_errorBoundary.ErrorBoundary, {
        globalOverlay: globalOverlay,
        isMounted: isMounted,
        onError: onComponentError
    }, children != null ? children : null), isMounted ? /*#__PURE__*/ React.createElement(_shadowPortal.ShadowPortal, {
        globalOverlay: globalOverlay
    }, /*#__PURE__*/ React.createElement(_cssReset.CssReset, null), /*#__PURE__*/ React.createElement(_base.Base, null), /*#__PURE__*/ React.createElement(_componentStyles.ComponentStyles, null), shouldPreventDisplay(hasBuildError ? 'build' : hasRuntimeErrors ? 'runtime' : null, preventDisplay) ? null : hasBuildError ? /*#__PURE__*/ React.createElement(_buildError.BuildError, {
        message: state.buildError
    }) : hasRuntimeErrors ? /*#__PURE__*/ React.createElement(_errors.Errors, {
        errors: state.errors
    }) : undefined) : undefined);
};
var _default = ReactDevOverlay;
exports.default = _default;

if ((typeof exports.default === 'function' || (typeof exports.default === 'object' && exports.default !== null)) && typeof exports.default.__esModule === 'undefined') {
  Object.defineProperty(exports.default, '__esModule', { value: true });
  Object.assign(exports.default, exports);
  module.exports = exports.default;
}

//# sourceMappingURL=ReactDevOverlay.js.map