import _extends from "@swc/helpers/src/_extends.mjs";
import * as React from 'react';
import * as Bus from './bus';
import { ShadowPortal } from './components/ShadowPortal';
import { BuildError } from './container/BuildError';
import { Errors } from './container/Errors';
import { ErrorBoundary } from './ErrorBoundary';
import { Base } from './styles/Base';
import { ComponentStyles } from './styles/ComponentStyles';
import { CssReset } from './styles/CssReset';
function reducer(state, ev) {
    switch(ev.type){
        case Bus.TYPE_BUILD_OK:
            {
                return _extends({}, state, {
                    buildError: null
                });
            }
        case Bus.TYPE_BUILD_ERROR:
            {
                return _extends({}, state, {
                    buildError: ev.message
                });
            }
        case Bus.TYPE_REFRESH:
            {
                return _extends({}, state, {
                    buildError: null,
                    errors: []
                });
            }
        case Bus.TYPE_UNHANDLED_ERROR:
        case Bus.TYPE_UNHANDLED_REJECTION:
            {
                return _extends({}, state, {
                    nextId: state.nextId + 1,
                    errors: [
                        ...state.errors.filter((err)=>{
                            // Filter out duplicate errors
                            return err.event.reason !== ev.reason;
                        }),
                        {
                            id: state.nextId,
                            event: ev
                        }, 
                    ]
                });
            }
        default:
            {
                // eslint-disable-next-line @typescript-eslint/no-unused-vars
                const _ = ev;
                return state;
            }
    }
}
const shouldPreventDisplay = (errorType, preventType)=>{
    if (!preventType || !errorType) {
        return false;
    }
    return preventType.includes(errorType);
};
const ReactDevOverlay = function ReactDevOverlay({ children , preventDisplay , globalOverlay  }) {
    const [state, dispatch] = React.useReducer(reducer, {
        nextId: 1,
        buildError: null,
        errors: []
    });
    React.useEffect(()=>{
        Bus.on(dispatch);
        return function() {
            Bus.off(dispatch);
        };
    }, [
        dispatch
    ]);
    const onComponentError = React.useCallback((_error, _componentStack)=>{
    // TODO: special handling
    }, []);
    const hasBuildError = state.buildError != null;
    const hasRuntimeErrors = Boolean(state.errors.length);
    const isMounted = hasBuildError || hasRuntimeErrors;
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ErrorBoundary, {
        globalOverlay: globalOverlay,
        isMounted: isMounted,
        onError: onComponentError
    }, children != null ? children : null), isMounted ? /*#__PURE__*/ React.createElement(ShadowPortal, {
        globalOverlay: globalOverlay
    }, /*#__PURE__*/ React.createElement(CssReset, null), /*#__PURE__*/ React.createElement(Base, null), /*#__PURE__*/ React.createElement(ComponentStyles, null), shouldPreventDisplay(hasBuildError ? 'build' : hasRuntimeErrors ? 'runtime' : null, preventDisplay) ? null : hasBuildError ? /*#__PURE__*/ React.createElement(BuildError, {
        message: state.buildError
    }) : hasRuntimeErrors ? /*#__PURE__*/ React.createElement(Errors, {
        errors: state.errors
    }) : undefined) : undefined);
};
export default ReactDevOverlay;

//# sourceMappingURL=ReactDevOverlay.js.map